@@ -16,7 +16,7 @@ import base64
 import json
 import traceback
 
-import sqlalchemy
+from oslo_db.sqlalchemy import session
 from sqlalchemy import orm
 from sqlalchemy.orm import scoping
 
@@ -32,7 +32,7 @@ class KekRewrap(object):
 
     def __init__(self, conf):
         self.dry_run = False
-        self.db_engine = sqlalchemy.create_engine(conf.sql_connection)
+        self.db_engine = session.create_engine(conf.sql_connection)
         self._session_creator = scoping.scoped_session(
             orm.sessionmaker(
                 bind=self.db_engine,
@@ -79,16 +79,18 @@ class KekRewrap(object):
             kek_data = iv + wrapped_key
             self.pkcs11.verify_hmac(kek_mkhk, hmac, kek_data, session)
             # Unwrap KEK
-            kek = self.pkcs11.unwrap_key(kek_mkek, iv, wrapped_key, session)
+            current_kek = self.pkcs11.unwrap_key(kek_mkek, iv, wrapped_key,
+                                                 session)
 
             # Wrap KEK with new master keys
-            new_kek = self.pkcs11.wrap_key(self.new_mkek, kek, session)
+            new_kek = self.pkcs11.wrap_key(self.new_mkek, current_kek,
+                                           session)
             # Compute HMAC for rewrapped KEK
             new_kek_data = new_kek['iv'] + new_kek['wrapped_key']
             new_hmac = self.pkcs11.compute_hmac(self.new_mkhk, new_kek_data,
                                                 session)
             # Destroy unwrapped KEK
-            self.pkcs11.destroy_object(kek, session)
+            self.pkcs11.destroy_object(current_kek, session)
 
             # Build updated meta dict
             updated_meta = meta_dict.copy()
@@ -148,7 +150,7 @@ class KekRewrap(object):
 
 
 def main():
-    script_desc = ('Utility to re-wrap project KEKs after rotating an MKEK.')
+    script_desc = 'Utility to re-wrap project KEKs after rotating an MKEK.'
 
     parser = argparse.ArgumentParser(description=script_desc)
     parser.add_argument(
