@@ -1,3 +1,16 @@
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """Add missing constraints
 
 Revision ID: 39a96e67e990
@@ -16,8 +29,8 @@ import sqlalchemy as sa
 
 def upgrade():
     # Add missing projects table keystone_id uniqueness constraint.
-    op.create_unique_constraint(
-            'uc_projects_external_ids', 'projects', ['external_id'])
+    op.create_unique_constraint('uc_projects_external_ids',
+                                'projects', ['external_id'])
 
     # Add missing default for secret_acls' project_access.
     op.alter_column('secret_acls', 'project_access',
