@@ -92,7 +92,7 @@ def hard_reset():
     setup_database_engine_and_factory()
 
 
-def setup_database_engine_and_factory():
+def setup_database_engine_and_factory(initialize_secret_stores=False):
     global sa_logger, _SESSION_FACTORY, _ENGINE
 
     LOG.info('Setting up database engine and session factory')
@@ -109,7 +109,8 @@ def setup_database_engine_and_factory():
     # session instance per thread.
     session_maker = sa_orm.sessionmaker(bind=_ENGINE)
     _SESSION_FACTORY = sqlalchemy.orm.scoped_session(session_maker)
-    _initialize_secret_stores_data()
+    if initialize_secret_stores:
+        _initialize_secret_stores_data()
 
 
 def start():
@@ -393,6 +394,7 @@ class BaseRepo(object):
             raise exception.Invalid(msg)
 
         LOG.debug("Begin create from...")
+        session = self.get_session(session)
         start = time.time()  # DEBUG
 
         # Validate the attributes before we go any further. From my
@@ -406,6 +408,7 @@ class BaseRepo(object):
             LOG.debug("Saving entity...")
             entity.save(session=session)
         except db_exc.DBDuplicateEntry as e:
+            session.rollback()
             LOG.exception('Problem saving entity for create')
             error_msg = re.sub('[()]', '', str(e.args))
             raise exception.ConstraintCheck(error=error_msg)
