@@ -19,8 +19,8 @@ import datetime
 import os
 from oslo_utils import uuidutils
 
-from Crypto.PublicKey import RSA
-from Crypto.Util import asn1
+from Crypto.PublicKey import RSA  # nosec
+from Crypto.Util import asn1  # nosec
 import pki
 
 subcas_available = True
@@ -118,10 +118,11 @@ def create_connection(conf, subsystem_path):
     pem_path = conf.dogtag_plugin.pem_path
     if pem_path is None:
         raise ValueError(u._("pem_path is required"))
+    # port is string type in PKIConnection
     connection = pki.client.PKIConnection(
         'https',
         conf.dogtag_plugin.dogtag_host,
-        conf.dogtag_plugin.dogtag_port,
+        str(conf.dogtag_plugin.dogtag_port),
         subsystem_path)
     connection.set_authentication_cert(pem_path)
     return connection
