@@ -34,7 +34,8 @@ symantec_plugin_opts = [
     cfg.StrOpt('username',
                help=u._('Symantec username for authentication')),
     cfg.StrOpt('password',
-               help=u._('Symantec password for authentication')),
+               help=u._('Symantec password for authentication'),
+               secret=True),
     cfg.StrOpt('url',
                help=u._('Domain of Symantec API'))
 ]
@@ -52,13 +53,13 @@ class SymantecCertificatePlugin(cert.CertificatePluginBase):
         self.password = conf.symantec_plugin.password
         self.url = conf.symantec_plugin.url
 
-        if self.username == None:
+        if self.username is None:
             raise ValueError(u._("username is required"))
 
-        if self.password == None:
+        if self.password is None:
             raise ValueError(u._("password is required"))
 
-        if self.url == None:
+        if self.url is None:
             raise ValueError(u._("url is required"))
 
     def get_default_ca_name(self):
