@@ -127,8 +127,7 @@ class WhenCreatingContainersUsingContainersResource(
         self.assertNotIn(self.project_id, resp.headers['Location'])
 
     def test_should_throw_exception_when_secret_ref_doesnt_exist(self):
-        config.CONF.set_override("host_href", "http://localhost:9311",
-                                 enforce_type=True)
+        config.CONF.set_override("host_href", "http://localhost:9311")
         secret_refs = [
             {
                 'name': 'bad secret',
@@ -315,7 +314,7 @@ class WhenAddingOrRemovingContainerSecretsUsingContainersSecretsResource(
     def test_should_add_container_secret_with_trailing_slash(self):
         resp, container_id = create_container(
             self.app,
-            name='test conatiner name',
+            name='test container name',
             container_type='generic',
         )
         self._assert_successful_container_create(resp, container_id)
