@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
+from oslo_utils import uuidutils
 
 from barbican.tests import utils
 from functionaltests.api import base
@@ -106,7 +106,7 @@ class RBACQuotasTestCase(base.TestCase):
     def test_rbac_get_quotas(self, user, admin, expected_return):
         """Test RBAC for get quotas
 
-        Issue a get quotas and verify that that the correct
+        Issue a get quotas and verify that the correct
         http return code comes back for the specified user.
 
         :param user: the user who will attempt to do the get
@@ -120,7 +120,7 @@ class RBACQuotasTestCase(base.TestCase):
     def test_rbac_get_project_quotas(self, user, admin, expected_return):
         """Test RBAC for get project quotas
 
-        Issue a get quotas and verify that that the correct
+        Issue a get quotas and verify that the correct
         http return code comes back for the specified user.
 
         :param user: the user who will attempt to do the get
@@ -134,7 +134,7 @@ class RBACQuotasTestCase(base.TestCase):
     def test_rbac_set_project_quotas(self, user, admin, expected_return):
         """Test RBAC for set project quotas
 
-        Issue a set project quotas and verify that that the correct
+        Issue a set project quotas and verify that the correct
         http return code comes back for the specified user.
 
         :param user: the user who will attempt to do the set
@@ -143,7 +143,7 @@ class RBACQuotasTestCase(base.TestCase):
         """
         request_model = quota_models.ProjectQuotaRequestModel(
             **get_set_project_quotas_request())
-        project_id = str(uuid.uuid4())
+        project_id = uuidutils.generate_uuid()
         resp = self.behaviors.set_project_quotas(project_id,
                                                  request_model,
                                                  user_name=user)
@@ -153,7 +153,7 @@ class RBACQuotasTestCase(base.TestCase):
     def test_rbac_delete_project_quotas(self, user, admin, expected_return):
         """Test RBAC for delete project quotas
 
-        Issue a set project quotas and verify that that the correct
+        Issue a set project quotas and verify that the correct
         http return code comes back for the specified user.
 
         :param user: the user who will attempt to do the delete
@@ -162,7 +162,7 @@ class RBACQuotasTestCase(base.TestCase):
         """
         request_model = quota_models.ProjectQuotaRequestModel(
             **get_set_project_quotas_request())
-        project_id = str(uuid.uuid4())
+        project_id = uuidutils.generate_uuid()
         resp = self.behaviors.set_project_quotas(project_id,
                                                  request_model,
                                                  user_name=service_admin)
