@@ -84,7 +84,7 @@ def get_passphrase_req():
 def get_default_data():
     return {
         "name": "AES key",
-        "expiration": "2020-02-28T19:14:44.180394",
+        "expiration": "2018-02-28T19:14:44.180394",
         "algorithm": "aes",
         "bit_length": 256,
         "mode": "cbc",
@@ -135,7 +135,7 @@ class SecretsTestCase(base.TestCase):
 
         self.default_secret_create_two_phase_data = {
             "name": "AES key",
-            "expiration": "2020-02-28T19:14:44.180394",
+            "expiration": "2018-02-28T19:14:44.180394",
             "algorithm": "aes",
             "bit_length": 256,
             "mode": "cbc",
@@ -530,8 +530,8 @@ class SecretsTestCase(base.TestCase):
         a valid secret.
         """
 
-        # create a secret that expires in 5 seconds
-        timestamp = utils.create_timestamp_w_tz_and_offset(seconds=5)
+        # create a secret that expires in 15 seconds
+        timestamp = utils.create_timestamp_w_tz_and_offset(seconds=15)
 
         test_model = secret_models.SecretModel(
             **self.default_secret_create_data)
@@ -544,8 +544,8 @@ class SecretsTestCase(base.TestCase):
         get_resp = self.behaviors.get_secret_metadata(secret_ref)
         self.assertEqual(200, get_resp.status_code)
 
-        # now wait 10 seconds
-        time.sleep(10)
+        # now wait 20 seconds
+        time.sleep(20)
 
         # now get the secret - should be invalid (expired)
         resp = self.behaviors.get_secret_metadata(secret_ref)
@@ -966,7 +966,7 @@ class SecretsTestCase(base.TestCase):
         # get Location field from result and assert that it is NOT the
         # malicious one.
         regex = '.*{0}.*'.format(malicious_hostname)
-        self.assertNotRegexpMatches(resp.headers['location'], regex)
+        self.assertNotRegex(resp.headers['location'], regex)
 
     @testcase.skipIf(base.conf_host_href_used, 'response href using '
                      'CONF.host_href instead of wsgi request')
@@ -991,7 +991,7 @@ class SecretsTestCase(base.TestCase):
             secret_ref, extra_headers=changed_host_header)
         # Check returned href has provided proxy hostname
         regex = '.*{0}.*'.format(another_proxy_hostname)
-        self.assertRegexpMatches(resp.model.secret_ref, regex)
+        self.assertRegex(resp.model.secret_ref, regex)
 
     @utils.parameterized_dataset({
         'symmetric': ['symmetric',
