@@ -26,7 +26,7 @@ from functionaltests.api.v1.models import secret_models
 
 create_secret_data = {
     "name": "AES key",
-    "expiration": "2020-02-28T19:14:44.180394",
+    "expiration": "2018-02-28T19:14:44.180394",
     "algorithm": "aes",
     "bit_length": 256,
     "mode": "cbc",
@@ -238,4 +238,4 @@ class ConsumersTestCase(base.TestCase):
         # get Location field from result and assert that it is NOT the
         # malicious one.
         regex = '.*{0}.*'.format(malicious_hostname)
-        self.assertNotRegexpMatches(resp.headers['location'], regex)
+        self.assertNotRegex(resp.headers['location'], regex)
