@@ -15,8 +15,18 @@
 # This script is executed inside post_test_hook function in devstack gate.
 
 # Install packages from test-requirements.txt
+
+set -ex
+
+plugin=$1
+
 sudo pip install -r /opt/stack/new/barbican/test-requirements.txt
 
 cd /opt/stack/new/barbican/functionaltests
 echo 'Running Functional Tests'
-sudo ./run_tests.sh
+
+if [ "$DEVSTACK_GATE_USE_PYTHON3" = True ]; then
+    export PYTHON=$(which python3 2>/dev/null)
+fi
+
+sudo -E ./run_tests.sh $plugin
